PersistentObjectStore

Struct PersistentObjectStore 

pub struct PersistentObjectStore<B> { /* private fields */ }
Persistent semantic object facet backed by an existing journal backend.

Implementations

Source

impl<B: JournalBackend> PersistentObjectStore<B>

pub fn open(backend: B) -> Result<Self, StoreError>

Opens the facet and verifies its rebuildable correspondence index.

pub fn into_inner(self) -> B

Returns the wrapped backend.