pub struct StoredDatumRef {
pub meaning: ContentId,
pub storage: ContentId,
}Expand description
A verified crossing from semantic Datum identity to physical byte identity.
Fields
meaning: ContentIdKernel Datum identity used by callers and journal entries.
storage: ContentIdExact-byte identity used only by the storage adapter.