pub struct HostDirJournalBackend { /* private fields */ }Expand description
Crash-durable journal composition over the canonical host-backed Table/Dir port.
state contains both fence and head. Its one compare-exchange is the only
publication linearization point. Objects and entries are immutable leaves.
Implementations
Sourceimpl HostDirJournalBackend
impl HostDirJournalBackend
Sourcepub fn open(
port: Arc<dyn HostDirPort>,
capabilities: BackendCapabilities,
work_bound: usize,
) -> Result<Self, JournalError>
pub fn open( port: Arc<dyn HostDirPort>, capabilities: BackendCapabilities, work_bound: usize, ) -> Result<Self, JournalError>
Opens a binding. Read operations remain available when write safety is absent.
Sourcepub fn with_failpoint_hook(
self,
hook: impl Fn(Failpoint) -> bool + Send + Sync + 'static,
) -> Self
pub fn with_failpoint_hook( self, hook: impl Fn(Failpoint) -> bool + Send + Sync + 'static, ) -> Self
Installs a deterministic test hook. Returning true simulates process death.
Sourcepub fn capabilities(&self) -> BackendCapabilities
pub fn capabilities(&self) -> BackendCapabilities
Reports the binding evidence used to admit or refuse write mode.