pub struct PersistentObjectStore<B> { /* private fields */ }Expand description
Persistent semantic object facet backed by an existing journal backend.
Implementations
Sourceimpl<B: JournalBackend> PersistentObjectStore<B>
impl<B: JournalBackend> PersistentObjectStore<B>
Sourcepub fn open(backend: B) -> Result<Self, StoreError>
pub fn open(backend: B) -> Result<Self, StoreError>
Opens the facet and verifies its rebuildable correspondence index.
Sourcepub fn into_inner(self) -> B
pub fn into_inner(self) -> B
Returns the wrapped backend.