PersistentSemanticObjects

Trait PersistentSemanticObjects 

pub trait PersistentSemanticObjects {
    // Required methods
    fn put(&mut self, value: Datum) -> Result<StoredDatumRef, StoreError>;
    fn get(&self, meaning: &ContentId) -> Result<Datum, StoreError>;
    fn rebuild_index(&mut self) -> Result<Vec<StoredDatumRef>, StoreError>;
}
Owned-return persistent Datum operations over the journal object backend.

Required Methods

fn put(&mut self, value: Datum) -> Result<StoredDatumRef, StoreError>

Stores a canonical value idempotently and returns both identities.

fn get(&self, meaning: &ContentId) -> Result<Datum, StoreError>

Resolves a value by semantic identity and verifies that identity again.

fn rebuild_index(&mut self) -> Result<Vec<StoredDatumRef>, StoreError>

Rebuilds and verifies the derived semantic-to-storage index.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors